Learn R Programming

ncf (version 1.1-2)

lisa.nc: Non-centered inidcators of spatial association

Description

lisa.nc is a function to estimate the (noncentred) local indicators of spatial association. The function requires multiple observations at each location. For single observations at each location use lisa

Usage

lisa.nc(x, y, z, neigh, na.rm = FALSE, resamp=1000, latlon = FALSE, quiet = FALSE)

Arguments

x
vector of length n representing the x coordinates (or latitude; see latlon).
y
vector of length n representing the y coordinates (or longitude).
z
a matrix of dimension n x p representing p (>1) observation at each location.
neigh
neighborhood size.
resamp
number of resamples under the NULL to generate p-values
latlon
Not yet implemented: if TRUE, coordinates are latitude and longitude.
na.rm
if TRUE, NA's will be dealt with through pairwise deletion of missing values.
quiet
if TRUE the counter is supressed during execution.

Value

  • An object of class "lisa" is returned, consisting of the following components:
  • nthe number of pairs within each neighborhood.
  • dmeanthe actual mean of distance within each neighborhood.
  • correlationthe mean correlation within the neighborhood (neigh).
  • pthe permutation two-sided p-value for each distance-class.
  • coorda list with the x and y coordinates.

Details

This is the function to estimate the (non-centered) local indicators of spatial association modified form Anselin (1995). 'correlation' is the average correlation within a neighborhood. The function requires multiple observations at each location. Missing values are allowed -- values are assumed missing at random.

References

Anselin, L. 1995. Local indicators of spatial association - LISA. Geographical Analysis 27:93-115.

See Also

lisa plot.lisa

Examples

Run this code
#first generate some sample data
    x <- expand.grid(1:20, 1:5)[,1]
    y <- expand.grid(1:20, 1:5)[,2]

#z data from an exponential random field
    z <- cbind(
        rmvn.spa(x=x, y=y, p=2, method="exp"),
        rmvn.spa(x=x, y=y, p=2, method="exp")
        )

#lisa.nc analysis
    fit1 <- lisa.nc(x=x, y=y, z=z, neigh=3)
    plot.lisa(fit1)

Run the code above in your browser using DataLab