Learn R Programming

ncf (version 1.2-2)

plot.Sncf: Plots nonparametric spatial correlation-functions

Description

The `plot' method for class "Sncf".

Usage

# S3 method for Sncf
plot(x, xmax = 0, ylim=c(-1,1), add = FALSE, …)

Arguments

x

an object of class "Sncf", usually, as a result of a call to Sncf (or Sncf.srf).

xmax

The maximal distance to be plotted on the x-axis. If set to zero the maximum distance in the data will be used.

ylim

Limits for the y-axis (default: -1, 1).

add

if TRUE the plot is added on to the previous graph.

other arguments

Value

A plot of the Nonparametric spatial covariance function (with CI's if boostrapps are available)

See Also

Sncf plot.Sncf Sncf.srf summary.Sncf