Learn R Programming

ncf (version 1.2-2)

plot.Sncf.cov: Plots nonparametric spatial covariance-functions

Description

'plot' method for class "Sncf.cov".

Usage

# S3 method for Sncf.cov
plot(x, xmax = 0, …)

Arguments

x

an object of class "Sncf.cov", usually, as a result of a call to Sncf.srf (with corr = FALSE).

xmax

The maximal distance to be plotted on the x-axis. If set to zero the maximum distance in the data will be used.

other arguments

See Also

Sncf.srf plot.Sncf