Learn R Programming

ncf (version 1.2-2)

plot.lisa: Plots local indicators of spatial association

Description

`plot' method for class "lisa".

Usage

# S3 method for lisa
plot(x, neigh.mean = FALSE, add=FALSE, inches=0.2, …)

Arguments

x

an object of class "lisa", ususally, as a result of a call to lisa.

neigh.mean

if TRUE size of symbols represents average observation in each neighborhood, if FALSE size of symbols represents the original observation

add

if TRUE, a lisa-plot will be added to a pre-existing plot

inches

scales the size of the symbols

other arguments

Value

A bubble-plot of observations against spatial coordinates is produced. Below mean values are signified by squares. Above mean values are signified by squares.

If a permutation test was performed, observations for which the associated LISA statistic is positive and significant at a nominal (two-sided) 5%-level will be respresented by filled symbols and non-significant values by open symbols. Thus spatial hot-spots are represented by red filled circles and cold-spots by black filled squares.

See Also

lisa lisa.nc