Learn R Programming

ncf (version 1.2-2)

plot.spline.correlog: Plots spline correlograms

Description

`plot' method for class "spline.correlog".

Usage

# S3 method for spline.correlog
plot(x, xmax = 0, ylim=c(-1,1), …)

Arguments

x

an object of class "spline.correlog", usually, as a result of a call to spline.correlog.

xmax

The maximal distance to be plotted on the x-axis. If set to zero the maximum distance in the data will be used.

ylim

Limits for the y-axis (default: -1, 1).

other arguments

Value

A plot of the spline correlogram function against distance is produced. 95% pointwise confidence (or null) envelopes are superimposed (if available).

See Also

spline.correlog summary.spline.correlog