Learn R Programming

ncf (version 1.2-2)

print.mSynch: Print function for mSynch objects

Description

`Print' method for class "mSynch".

Usage

# S3 method for mSynch
print(x, verbose = FALSE, …)

Arguments

x

an object of class "mSynch", usually, as a result of a call to mSynch).

verbose

if TRUE a raw listing of the object is produced. if FALSE a summary list is produced

other arguments

Value

If verbose is FALSE a list summarizing the regional correlation is produced:

mean

the regional mean correlation.

Squantile

the quantile distribution from the resampling for the regional correlation.

See Also

mSynch