Learn R Programming

ncf (version 1.1-7)

summary.spline.correlog: Summarizing spline correlograms

Description

`Summary' method for class "spline.correlog".

Usage

"summary"(object, ...)

Arguments

object
an object of class "spline.correlog", usually, as a result of a call to spline.correlog.
...
other arguments

Value

A list summarizing spline correlograms is returned.
estimates
a vector of benchmark statistics:
$x
is the lowest value at which the function is = 0. If correlation is initially negative, the distance calculated appears as a negative measure.
$e
is the lowest value at which the function is <= 1="" e.<="" dd="">
$y
is the extrapolated value at x=0.
quantiles
A matrix summarizing the quantiles in the bootstrap (or null) distributions of the benchmark statistics.

See Also

spline.correlog plot.spline.correlog