The `plot' method for class "Sncf".
# S3 method for Sncf
plot(x, xmax = 0, ylim=c(-1,1), add = FALSE, …)an object of class "Sncf", usually, as
a result of a call to Sncf (or Sncf.srf).
The maximal distance to be plotted on the x-axis. If set to zero the maximum distance in the data will be used.
Limits for the y-axis (default: -1, 1).
if TRUE the plot is added on to the previous graph.
other arguments
A plot of the Nonparametric spatial covariance function (with CI's if boostrapps are available)