`plot' method for class "spline.correlog".
# S3 method for spline.correlog
plot(x, xmax = 0, ylim=c(-1,1), …)an object of class "spline.correlog", usually,
as a result of a call to spline.correlog.
The maximal distance to be plotted on the x-axis. If set to zero the maximum distance in the data will be used.
Limits for the y-axis (default: -1, 1).
other arguments
A plot of the spline correlogram function against distance is produced. 95% pointwise confidence (or null) envelopes are superimposed (if available).