`Print' method for class "mSynch".
# S3 method for mSynch
print(x, verbose = FALSE, …)an object of class "mSynch", usually, as a result of a call to mSynch).
if TRUE a raw listing of the object is produced. if FALSE a summary list is produced
other arguments
If verbose is FALSE a list summarizing the regional correlation is produced:
the regional mean correlation.
the quantile distribution from the resampling for the regional correlation.