Learn R Programming

ncf (version 1.1-2)

summary.spline.correlog: Summarizing spline correlograms

Description

`Summary' method for class "spline.correlog".

Usage

## S3 method for class 'spline.correlog':
summary(object, \dots)

Arguments

object
an object of class "spline.correlog", usually, as a result of a call to spline.correlog.
...
other arguments

Value

  • A list summarizing spline correlograms is returned.
  • estimatesa vector of benchmark statistics:
  • $xis the lowest value at which the function is = 0. If correlation is initially negative, the distance calculated appears as a negative measure.
  • $eis the lowest value at which the function is <= 1="" e.<="" description="">
  • $yis the extrapolated value at x=0.
  • quantilesA matrix summarizing the quantiles in the bootstrap (or null) distributions of the benchmark statistics.

See Also

spline.correlog plot.spline.correlog